<#	
	.NOTES
	===========================================================================
	 Created with: 	SAPIEN Technologies, Inc., PowerShell Studio 2019 v5.6.159
	 Created on:   	5/27/2019 9:49 AM
	 Created by:   	Maximo Trinidad
	 Organization: 	SAPIEN Technologies, Inc.
	 Filename:     	Get-SystemInfo.ps1
	===========================================================================
	.DESCRIPTION
		Get-SystemInfo gets the system information from 0ne or more computers.
		This Get-SystemInfo.exe version is for packaged executable only.
	.RELATED LINKS	
		https://info.sapien.com/index.php/packaging-deployment/parsing-parameters-for-a-script-in-an-executable-file
		https://info.sapien.com/index.php/packaging-deployment/passing-parameters-to-a-script-in-an-executable-file
		https://info.sapien.com/index.php/packaging-deployment/displaying-help-for-a-script-in-an-executable-file
		https://devblogs.microsoft.com/scripting/how-to-use-powershell-to-write-to-event-logs/	
#>

[CmdletBinding()]
param
(
	[string]$ComputerName,
	[ValidateSet('True', 'False')]
	[string]$Help
)

function WriteTo-MyEventlog
{
	[CmdletBinding()]
	param ()
	
	## - Write to the Windows PowerShell Eventlog:
	[string]$EventResult = ($SystemInfoObj | Format-List | Out-String -Width 1000);
	
	## - Values provided: LogName, ComputerName, Source
	$Eventlog = New-Object System.Diagnostics.Eventlog("Application", $env:COMPUTERNAME, "Custom Script Get-SystemInformation");
	
	## - Values provided: Message, EntryLevel, EventID
	$Eventlog.WriteEntry("Output Result: $EventResult", 'Information', '100');
	
};

## - Code to display script Help in executable format:
If ($Help -ne 'True')
{
	## - Code to handle string array in script executable format:
	if ($ComputerName.Contains(',') -eq $true)
	{
		[array]$ComputerNameList = $ComputerName.Split(',').Trim().replace("'", '');
	}
	else
	{
		[string]$ComputerNameList = $ComputerName;
	};
	
	## - Section for collect System Information:
	foreach ($computer in $ComputerNameList)
	{
		
		## - Using WMI to collect system information:
		$os = get-wmiObject -Class Win32_OperatingSystem -Computername $computer `
							-ErrorAction 'SilentlyContinue' -ErrorVariable MyError;
		$cs = get-wmiObject -Class Win32_ComputerSystem -Computername $computer `
							-ErrorAction 'SilentlyContinue' -ErrorVariable MyError;
		
		## - Error Check:
		if ($($MyError | Select exception) -eq $Null)
		{
			
			## - Build PSCustomObject:
			[PSCustomObject]$SystemInfoObj = New-Object PSObject -Property @{
				SubmittedName    = $computer;
				ComputerName	 = $os.csname;
				OperatingSystem  = $os.Name.Split('|')[0];
				LastBootUpTime   = $os.ConvertToDateTime($os.LastBootUpTime);
				Status		     = "Success";
				Manufacturer	 = $cs.manufacturer;
				SystemModel	     = $cs.model;
				'PhysicalMemory(GB)' = [float]($cs.TotalPhysicalMemory/1gb);
			};
			## - Display results:
			Write-Output $SystemInfoObj;
			
			## - Write result to the event log:
			WriteTo-MyEventlog;
		}
		else
		{
			$SystemInfoObj = $computer `
			| Select-Object `
							@{ Label = 'ComputerName'; Expression = { $computer } }, `
							@{ Label = 'Status'; Expression = { ('Failed - ' + (([string]$MyError[0]).split("`n")).split("(E")[0]) } };
			Write-Output $SystemInfoObj;
			
			## - Write result to the event log:
			WriteTo-MyEventlog;
		};
		
	};
}
else
{
	## - Help Information:
	@"
----------------------------------------------------------------------------

NAME
Get-SystemInfo.exe

SYNOPSIS
Get System Information

SYNTAX
Get-SystemInfo.exe
    [[-ComputerName] <String>] [[-Help] <String>] [<CommonParameters>]

DESCRIPTION
    Get-SystemInfo.exe gets the system information from 0ne or more computers.
    This Get-SystemInfo.exe version is for [ackaged executable only.

EXAMPLE 1: Get system information of one computer
Get-SystemInfo.exe -Computername SAPIEN01

EXAMPLE 2: Get system information of an array of computer names separated by commas
Get-SystemInfo.exe -ComputerName "SAPIEN01,127.0.0.1"

EXAMPLE 3: Display Help for Get-SystemInfo.exe:
Get-SystemInfo.exe -Help True

----------------------------------------------------------------------------
"@
};

